Skip to contents

Mainly used within omics and other functions to check if given column name does exist in the table and is not completely empty (containing NAs).

Usage

column_exists(column, table)

Arguments

column

A character of length 1.

table

A data.table or data.frame.

Value

A boolean value.