Mainly used within omics and other functions to check if given column name does exist in the table and is not completely empty (containing NAs).
Arguments
- column
A character of length 1.
- table
A data.table or data.frame.
Mainly used within omics and other functions to check if given column name does exist in the table and is not completely empty (containing NAs).
A character of length 1.
A data.table or data.frame.