This is a sub-class that is compatible to preprocessed data obtained from https://fragpipe.nesvilab.org/.
It inherits all methods from the abstract class omics and only adapts the initialize function.
It supports pre-existing data structures or paths to text files.
When omics data is very large, data loading becomes very expensive. It is therefore recommended to use the reset() method to reset your changes.
Every omics class creates an internal memory efficient back-up of the data, the resetting of changes is an instant process.
Super class
omics -> proteomics
Active bindings
treeDataA "phylo" class, see as.phylo.
Methods
Inherited methods
omics$alpha_diversity()omics$autoFlow()omics$composition()omics$copy()omics$distance()omics$feature_merge()omics$feature_subset()omics$foldchange()omics$ordination()omics$print()omics$rankstat()omics$removeNAs()omics$reset()omics$sample_subset()omics$samplepair_subset()omics$scale()omics$validate()
proteomics$new()
Initializes the proteomics class object with proteomics$new()
Usage
proteomics$new(
countData = NULL,
metaData = NULL,
featureData = NULL,
treeData = NULL
)Arguments
countDataA path to an existing file or a dense/sparse Matrix format.
metaDataA path to an existing file, data.table or data.frame.
featureDataA path to an existing file, data.table or data.frame.
treeDataA path to an existing newick file or class "phylo", see read.tree.